// libraries import
#include <Servo.h>

// giving a name to the pins of different sensors and actuators
#define TRIG 4
#define ECHO 3
#define SERVO 5


// declaring global variables to be used later, and creating an instance of a servo
long duration;
int distance;

int angle;
Servo servo;


void setup() {
  // setting sensors and actuaors as in- and output
  pinMode(TRIG, OUTPUT);
  pinMode(ECHO, INPUT);
  // telling the servo what pin it is on, and resetting to an angle of 9 degrees
  servo.attach(SERVO);
  servo.write(0);
}

void loop() {
  // clears the TRIG condition
  digitalWrite(TRIG, LOW);
  delayMicroseconds(2);
  // 10 microsends burst to TRIG
  digitalWrite(TRIG, HIGH);
  delayMicroseconds(10);
  digitalWrite(TRIG, LOW);
  // read the ECHO pin for sound wave travel time in microseconds
  duration = pulseIn(ECHO, HIGH);
  // convert to cm using speed of sounds (about 340m/s), but divided by two since the soundwave travels the distance twice
  distance = duration * 0.017;

  //Servo control based on distance
  if (distance > 300) {
    servoTry(0);
  }  else if (distance > 200) {
    servoTry(45);
  } else if (distance > 100) {
    servoTry(90);
  } else {
    servoTry(135);
  }
  
  delay(500);
}
// Checks if the angle needs to be changed, checks if it needs to increase or decrease and slowly rotates it to the correct angle with a delay between each degree of rotation. 
void servoTry(int goal) {
  if (goal != angle) {
    int diff;
    if (goal > angle) {
      for (int i = angle; i < goal; i++) {
        servo.write(i);
        delay(15);
      }
    } else {
      for (int i = angle; i > goal; i--) {
        servo.write(i);
        delay(15);
      }
    }
    angle = goal;
  }
}
